==> stylish-haskell-0.8.1.0-18-i686.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.8.1.0
id: stylish-haskell-0.8.1.0-3KskLpFtykd1ou84J1UsmC
key: stylish-haskell-0.8.1.0-3KskLpFtykd1ou84J1UsmC
license: BSD3
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
abi: b2c4ff9fbd0f97a05dddfdb340ce4062
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/stylish-haskell-0.8.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/stylish-haskell-0.8.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.8.1.0-3KskLpFtykd1ou84J1UsmC
depends:
    aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn base-4.10.0.0
    bytestring-0.10.8.2 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    yaml-0.8.23.3-Hxrrlqfmicr4pp6WmaArsD
abi-depends: aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn=002a869bdbfad797ec5fba636ef9d0d8
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             yaml-0.8.23.3-Hxrrlqfmicr4pp6WmaArsD=2eb35475272bb52d4b23b237d5ff79ed
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.8.1.0-19-i686.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.8.1.0
id: stylish-haskell-0.8.1.0-BCdV2dOq25J5EsPYaKoa7F
key: stylish-haskell-0.8.1.0-BCdV2dOq25J5EsPYaKoa7F
license: BSD3
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
abi: 726305fcb580d28f3c38390b012fa92e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/stylish-haskell-0.8.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/stylish-haskell-0.8.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.8.1.0-BCdV2dOq25J5EsPYaKoa7F
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0
    bytestring-0.10.8.2 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             yaml-0.8.23.3-5PA6FoFimacABkGYYUI5Gr=3efef415fb37938945c14dfc2fd6675d
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
